// Parallax effect
// Adapted from @ilonacodes article ->  https://link.medium.com/7fFiON6Q1X

const setupParallax = () => {

  // determine mobile devices by those which have a touch screen
  const isMobile = () => {
    var match = window.matchMedia || window.msMatchMedia;
    if(match) {
      var mq = match("(pointer:coarse)");
      return mq.matches;
    }
    return false;
  };

  if (isMobile()) return;

  const navEl = document.getElementById("nav");

  // for throttling
  let time;
  const wait = 5;

  const parallax = () => {

    if (time && (time + wait - Date.now()) >= 0) return;
    time = Date.now();

    const navHeight = navEl.getBoundingClientRect().height;

    const scrolled = window.pageYOffset;
    const viewportHeight = document.documentElement.clientHeight - navHeight;

    const imgHeight = Math.min(1000, viewportHeight);

    document.querySelectorAll(".parallax").forEach((img) => {

      const wrapper = img.parentNode;
      const wrapperHeight = wrapper.clientHeight;

      const slope = -(wrapperHeight + imgHeight)
                  / (viewportHeight + wrapperHeight);


      const fromTop = wrapper.getBoundingClientRect().top
                    + document.documentElement.scrollTop
                    - scrolled;

      const translateY = (slope * (fromTop + wrapperHeight))
                       + wrapperHeight
                       + navHeight;

      img.style["transform"] = "translate(-50%, "+translateY+"px)";
      img.style["height"] = imgHeight+"px";
    });

  };

  window.addEventListener('scroll', parallax, {passive: true});

  const resizeObserver = new ResizeObserver(parallax);
  resizeObserver.observe(navEl);
  resizeObserver.observe(window);

  parallax();
};

setupParallax();
